==> phpunit_9.6.7.orig.tar.xz: phpunit-9.6.7/tests/unit/Framework/Constraint/ClassHasAttributeTest.php <==
<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\Framework\Constraint;

use function sprintf;
use PHPUnit\Framework\ExpectationFailedException;
use PHPUnit\Framework\TestFailure;
use PHPUnit\TestFixture\ClassWithNonPublicAttributes;
use stdClass;

/**
 * @small
 */
final class ClassHasAttributeTest extends ConstraintTestCase
{
    public function testConstraintClassHasAttribute(): void
    {
        $constraint = new ClassHasAttribute(
            'privateAttribute'
        );

        $this->assertTrue($constraint->evaluate(ClassWithNonPublicAttributes::class, '', true));
        $this->assertFalse($constraint->evaluate(stdClass::class, '', true));
        $this->assertEquals('has attribute "privateAttribute"', $constraint->toString());
        $this->assertCount(1, $constraint);

        try {
            $constraint->evaluate(stdClass::class);
        } catch (ExpectationFailedException $e) {
            $this->assertEquals(
                sprintf(
                    <<<'EOF'
Failed asserting that class "%s" has attribute "privateAttribute".

EOF
                    ,
                    stdClass::class
                ),
                TestFailure::exceptionToString($e)
            );

            return;
        }

        $this->fail();
    }

    public function testConstraintClassHasAttribute2(): void
    {
        $constraint = new ClassHasAttribute(
            'privateAttribute'
        );

        try {
            $constraint->evaluate(stdClass::class, 'custom message');
        } catch (ExpectationFailedException $e) {
            $this->assertEquals(
                sprintf(
                    <<<'EOF'
custom message
Failed asserting that class "%s" has attribute "privateAttribute".

EOF
                    ,
                    stdClass::class
                ),
                TestFailure::exceptionToString($e)
            );

            return;
        }

        $this->fail();
    }
}

==> phpunit_9.6.17.orig.tar.xz: phpunit-9.6.17/tests/unit/Framework/Constraint/ClassHasAttributeTest.php <==
<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\Framework\Constraint;

use function sprintf;
use PHPUnit\Framework\ExpectationFailedException;
use PHPUnit\Framework\TestFailure;
use PHPUnit\TestFixture\ClassWithNonPublicAttributes;
use stdClass;

/**
 * @small
 */
final class ClassHasAttributeTest extends ConstraintTestCase
{
    public function testConstraintClassHasAttribute(): void
    {
        $constraint = new ClassHasAttribute(
            'privateAttribute',
        );

        $this->assertTrue($constraint->evaluate(ClassWithNonPublicAttributes::class, '', true));
        $this->assertFalse($constraint->evaluate(stdClass::class, '', true));
        $this->assertEquals('has attribute "privateAttribute"', $constraint->toString());
        $this->assertCount(1, $constraint);

        try {
            $constraint->evaluate(stdClass::class);
        } catch (ExpectationFailedException $e) {
            $this->assertEquals(
                sprintf(
                    <<<'EOF'
Failed asserting that class "%s" has attribute "privateAttribute".

EOF
                    ,
                    stdClass::class,
                ),
                TestFailure::exceptionToString($e),
            );

            return;
        }

        $this->fail();
    }

    public function testConstraintClassHasAttribute2(): void
    {
        $constraint = new ClassHasAttribute(
            'privateAttribute',
        );

        try {
            $constraint->evaluate(stdClass::class, 'custom message');
        } catch (ExpectationFailedException $e) {
            $this->assertEquals(
                sprintf(
                    <<<'EOF'
custom message
Failed asserting that class "%s" has attribute "privateAttribute".

EOF
                    ,
                    stdClass::class,
                ),
                TestFailure::exceptionToString($e),
            );

            return;
        }

        $this->fail();
    }
}
